# Library for validation process monitoring

*Nefertem* is a library that produces a set of metadata during the data validation process operated by some validation framework and allows data and reporting persistence as artifacts.
